Cache class

Constructors

Cache()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → List<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addName(String name) → bool
getCache(String path) → DartResult?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCache(String path, DartResult result) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited